@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2005, 2007, 
-   2009 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2005, 2007, 2009, 2010 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -803,7 +803,8 @@ mta_smtp (int argc, char **argv)
     {
       fd_set rfds;
       struct sockaddr_in his_addr;
-      int sfd, len, status;
+      int sfd, status;
+      socklen_t len;
 
       FD_ZERO (&rfds);
       FD_SET (fd, &rfds);
