@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2005,
-   2006, 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005, 2006, 2007, 2009, 2010
+   Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -410,8 +410,8 @@ extern int ml_got_interrupt (void);
 extern void ml_clear_interrupt (void);
 extern void ml_readline_init (void);
 extern int ml_reread (const char *prompt, char **text);
-extern char *ml_readline (char *prompt);
-extern char *ml_readline_with_intr (char *prompt);
+extern char *ml_readline (const char *prompt);
+extern char *ml_readline_with_intr (const char *prompt);
 
 extern char *alias_expand (const char *name);
 extern void alias_destroy (const char *name);
@@ -476,6 +476,7 @@ extern char **exec_compl (int argc, char **argv, int ws);
 # define alias_compl NULL
 # define var_compl NULL
 # define exec_compl NULL     
+# define mailvar_set_compl NULL
 #endif
 
 #ifdef __cplusplus
