@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003, 2005, 2006, 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2005, 2006, 2007, 2009, 2010 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -698,7 +699,8 @@ eval_body (struct eval_env *env)
       if (encoding)
 	{
 	  int rc = mu_filter_create(&dstr, input, encoding,
-				 MU_FILTER_DECODE, MU_STREAM_READ);
+				    MU_FILTER_DECODE, 
+				    MU_STREAM_READ | MU_STREAM_NO_CLOSE);
 	  if (rc == 0)
 	    input = dstr;
 	  free (encoding);
